pub struct DecreasePosition4 {
pub params: DecreasePosition4Params,
}Fields
params: DecreasePosition4ParamsTrait Implementations
Sourceimpl ArrangeAccounts for DecreasePosition4
impl ArrangeAccounts for DecreasePosition4
type ArrangedAccounts = DecreasePosition4InstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for DecreasePosition4
impl BorshDeserialize for DecreasePosition4
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreasePosition4
impl CarbonDeserialize for DecreasePosition4
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreasePosition4
impl Clone for DecreasePosition4
Sourcefn clone(&self) -> DecreasePosition4
fn clone(&self) -> DecreasePosition4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecreasePosition4
impl Debug for DecreasePosition4
Sourceimpl<'de> Deserialize<'de> for DecreasePosition4
impl<'de> Deserialize<'de> for DecreasePosition4
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DecreasePosition4
impl Hash for DecreasePosition4
Sourceimpl PartialEq for DecreasePosition4
impl PartialEq for DecreasePosition4
Sourceimpl Serialize for DecreasePosition4
impl Serialize for DecreasePosition4
impl Eq for DecreasePosition4
impl StructuralPartialEq for DecreasePosition4