pub struct DecreasePositionPostSwapEvent {
pub position_request_key: Pubkey,
pub swap_amount: u64,
pub jupiter_minimum_out: Option<u64>,
}Fields
position_request_key: Pubkeyswap_amount: u64jupiter_minimum_out: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for DecreasePositionPostSwapEvent
impl BorshDeserialize for DecreasePositionPostSwapEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreasePositionPostSwapEvent
impl CarbonDeserialize for DecreasePositionPostSwapEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreasePositionPostSwapEvent
impl Clone for DecreasePositionPostSwapEvent
Sourcefn clone(&self) -> DecreasePositionPostSwapEvent
fn clone(&self) -> DecreasePositionPostSwapEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DecreasePositionPostSwapEvent
impl<'de> Deserialize<'de> for DecreasePositionPostSwapEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DecreasePositionPostSwapEvent
impl Hash for DecreasePositionPostSwapEvent
Sourceimpl PartialEq for DecreasePositionPostSwapEvent
impl PartialEq for DecreasePositionPostSwapEvent
Sourcefn eq(&self, other: &DecreasePositionPostSwapEvent) -> bool
fn eq(&self, other: &DecreasePositionPostSwapEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DecreasePositionPostSwapEvent
impl StructuralPartialEq for DecreasePositionPostSwapEvent