pub struct DecreasePositionWithInternalSwap {
pub params: DecreasePositionWithInternalSwapParams,
}Fields
params: DecreasePositionWithInternalSwapParamsTrait Implementations
Sourceimpl ArrangeAccounts for DecreasePositionWithInternalSwap
impl ArrangeAccounts for DecreasePositionWithInternalSwap
type ArrangedAccounts = DecreasePositionWithInternalSwapInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for DecreasePositionWithInternalSwap
impl BorshDeserialize for DecreasePositionWithInternalSwap
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreasePositionWithInternalSwap
impl CarbonDeserialize for DecreasePositionWithInternalSwap
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreasePositionWithInternalSwap
impl Clone for DecreasePositionWithInternalSwap
Sourcefn clone(&self) -> DecreasePositionWithInternalSwap
fn clone(&self) -> DecreasePositionWithInternalSwap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DecreasePositionWithInternalSwap
impl<'de> Deserialize<'de> for DecreasePositionWithInternalSwap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DecreasePositionWithInternalSwap
impl PartialEq for DecreasePositionWithInternalSwap
Sourcefn eq(&self, other: &DecreasePositionWithInternalSwap) -> bool
fn eq(&self, other: &DecreasePositionWithInternalSwap) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DecreasePositionWithInternalSwap
impl StructuralPartialEq for DecreasePositionWithInternalSwap