pub struct InstantDecreasePosition {
pub params: InstantDecreasePositionParams,
}Fields
params: InstantDecreasePositionParamsTrait Implementations
Sourceimpl ArrangeAccounts for InstantDecreasePosition
impl ArrangeAccounts for InstantDecreasePosition
type ArrangedAccounts = InstantDecreasePositionInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for InstantDecreasePosition
impl BorshDeserialize for InstantDecreasePosition
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for InstantDecreasePosition
impl CarbonDeserialize for InstantDecreasePosition
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for InstantDecreasePosition
impl Clone for InstantDecreasePosition
Sourcefn clone(&self) -> InstantDecreasePosition
fn clone(&self) -> InstantDecreasePosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstantDecreasePosition
impl Debug for InstantDecreasePosition
Sourceimpl<'de> Deserialize<'de> for InstantDecreasePosition
impl<'de> Deserialize<'de> for InstantDecreasePosition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InstantDecreasePosition
impl Hash for InstantDecreasePosition
Sourceimpl PartialEq for InstantDecreasePosition
impl PartialEq for InstantDecreasePosition
Sourceimpl Serialize for InstantDecreasePosition
impl Serialize for InstantDecreasePosition
impl Eq for InstantDecreasePosition
impl StructuralPartialEq for InstantDecreasePosition