pub struct InstantDecreasePositionEvent {Show 19 fields
pub position_key: Pubkey,
pub position_side: u8,
pub position_custody: Pubkey,
pub position_collateral_custody: Pubkey,
pub position_size_usd: u64,
pub position_mint: Pubkey,
pub desired_mint: Pubkey,
pub has_profit: bool,
pub pnl_delta: u64,
pub owner: Pubkey,
pub pool: Pubkey,
pub size_usd_delta: u64,
pub transfer_amount_usd: u64,
pub transfer_token: u64,
pub price: u64,
pub price_slippage: u64,
pub fee_usd: u64,
pub open_time: i64,
pub referral: Option<Pubkey>,
}Fields
position_key: Pubkeyposition_side: u8position_custody: Pubkeyposition_collateral_custody: Pubkeyposition_size_usd: u64position_mint: Pubkeydesired_mint: Pubkeyhas_profit: boolpnl_delta: u64owner: Pubkeypool: Pubkeysize_usd_delta: u64transfer_amount_usd: u64transfer_token: u64price: u64price_slippage: u64fee_usd: u64open_time: i64referral: Option<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for InstantDecreasePositionEvent
impl BorshDeserialize for InstantDecreasePositionEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for InstantDecreasePositionEvent
impl CarbonDeserialize for InstantDecreasePositionEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for InstantDecreasePositionEvent
impl Clone for InstantDecreasePositionEvent
Sourcefn clone(&self) -> InstantDecreasePositionEvent
fn clone(&self) -> InstantDecreasePositionEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstantDecreasePositionEvent
impl Debug for InstantDecreasePositionEvent
Sourceimpl<'de> Deserialize<'de> for InstantDecreasePositionEvent
impl<'de> Deserialize<'de> for InstantDecreasePositionEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InstantDecreasePositionEvent
impl Hash for InstantDecreasePositionEvent
Sourceimpl PartialEq for InstantDecreasePositionEvent
impl PartialEq for InstantDecreasePositionEvent
Sourcefn eq(&self, other: &InstantDecreasePositionEvent) -> bool
fn eq(&self, other: &InstantDecreasePositionEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InstantDecreasePositionEvent
impl StructuralPartialEq for InstantDecreasePositionEvent