pub struct UpdateDecreasePositionRequest2 {
pub params: UpdateDecreasePositionRequest2Params,
}Fields
params: UpdateDecreasePositionRequest2ParamsTrait Implementations
Sourceimpl ArrangeAccounts for UpdateDecreasePositionRequest2
impl ArrangeAccounts for UpdateDecreasePositionRequest2
type ArrangedAccounts = UpdateDecreasePositionRequest2InstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateDecreasePositionRequest2
impl BorshDeserialize for UpdateDecreasePositionRequest2
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateDecreasePositionRequest2
impl CarbonDeserialize for UpdateDecreasePositionRequest2
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateDecreasePositionRequest2
impl Clone for UpdateDecreasePositionRequest2
Sourcefn clone(&self) -> UpdateDecreasePositionRequest2
fn clone(&self) -> UpdateDecreasePositionRequest2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateDecreasePositionRequest2
impl<'de> Deserialize<'de> for UpdateDecreasePositionRequest2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UpdateDecreasePositionRequest2
impl PartialEq for UpdateDecreasePositionRequest2
Sourcefn eq(&self, other: &UpdateDecreasePositionRequest2) -> bool
fn eq(&self, other: &UpdateDecreasePositionRequest2) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateDecreasePositionRequest2
impl StructuralPartialEq for UpdateDecreasePositionRequest2